"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cafs_1 = require("@pnpm/cafs");
const package_requester_1 = require("@pnpm/package-requester");
const pkgid_to_filename_1 = require("@pnpm/pkgid-to-filename");
const path = require("path");
const writeJsonFile = require("write-json-file");
const createImportPackage_1 = require("./createImportPackage");
const prune_1 = require("./prune");
async function default_1(resolve, fetchers, initOpts) {
    const storeDir = initOpts.storeDir;
    const packageRequester = package_requester_1.default(resolve, fetchers, {
        ignoreFile: initOpts.ignoreFile,
        networkConcurrency: initOpts.networkConcurrency,
        storeDir: initOpts.storeDir,
        verifyStoreIntegrity: initOpts.verifyStoreIntegrity,
    });
    const impPkg = createImportPackage_1.default(initOpts.packageImportMethod);
    const cafsDir = path.join(storeDir, 'files');
    const getFilePathByModeInCafs = cafs_1.getFilePathByModeInCafs.bind(null, cafsDir);
    const importPackage = (to, opts) => {
        const filesMap = {};
        for (const [fileName, fileMeta] of Object.entries(opts.filesResponse.filesIndex)) {
            filesMap[fileName] = getFilePathByModeInCafs(fileMeta.integrity, fileMeta.mode);
        }
        return impPkg(to, { filesMap, fromStore: opts.filesResponse.fromStore, force: opts.force });
    };
    return {
        close: async () => { },
        fetchPackage: packageRequester.fetchPackageToStore,
        getPackageLocation,
        importPackage,
        prune: prune_1.default.bind(null, storeDir),
        requestPackage: packageRequester.requestPackage,
        upload,
    };
    async function getPackageLocation(packageId, packageName, opts) {
        if (opts.targetEngine) {
            const sideEffectsCacheLocation = (await package_requester_1.getCacheByEngine(initOpts.storeDir, packageId))[opts.targetEngine];
            if (sideEffectsCacheLocation) {
                return {
                    dir: sideEffectsCacheLocation,
                    isBuilt: true,
                };
            }
        }
        return {
            dir: path.join(initOpts.storeDir, pkgid_to_filename_1.default(packageId, opts.lockfileDir), 'node_modules', packageName),
            isBuilt: false,
        };
    }
    async function upload(builtPkgLocation, opts) {
        const filesIndex = await packageRequester.cafs.addFilesFromDir(builtPkgLocation);
        // TODO: move this to a function
        // This is duplicated in @pnpm/package-requester
        const integrity = {};
        await Promise.all(Object.keys(filesIndex)
            .map(async (filename) => {
            const fileIntegrity = await filesIndex[filename].generatingIntegrity;
            integrity[filename] = {
                integrity: fileIntegrity.toString(),
                mode: filesIndex[filename].mode,
                size: filesIndex[filename].size,
            };
        }));
        const cachePath = path.join(storeDir, opts.packageId, 'side_effects', opts.engine);
        await writeJsonFile(path.join(cachePath, 'integrity.json'), integrity, { indent: undefined });
    }
}
exports.default = default_1;
//# sourceMappingURL=index.js.map